Learn R Programming

blindspiker (version 0.2.0)

blindspiker-package: blindspiker: Laboratory Blind Spike Sample Analyses

Description

A blind spike program provides samples to a laboratory in order to perform quality control (QC) checks. The samples provided are of a known quantity to the tester. The laboratory is typically uninformed of that the sample provided is a QC sample.

Arguments

Author

Maintainer: Mark Hogue mark.hogue.chp@gmail.com

See Also