Learn R Programming

blindspiker (version 0.2.0)

spike_combos: Count combinations of spiked samples

Description

A summary of spiked samples is provided based on combinations of interest.

Usage

spike_combos(analytes, dat = bs_df)

Value

table of combinations of analytes in blind spikes

Arguments

analytes

a vector of analytes of interest

dat

data frame with all data needed as described in `bs_prep_and_analysis`. Default is `bs_df`.

Examples

Run this code

example_spike_data <- system.file('extdata', 'spikevals.csv', package = 'blindspiker')
example_lab_data <- system.file('extdata', 'labvals.csv', package = 'blindspiker')
example_df <- bs_prep_and_analysis(spike_data = example_spike_data, lab_data = example_lab_data)
spike_combos(analytes = c('unknownium', 'Sr-90'), dat = example_df)

Run the code above in your browser using DataLab